@@ -23,14 +23,15 @@ import java.util.concurrent.atomic.AtomicReference;
 import java.util.concurrent.locks.Lock;
 import java.util.concurrent.locks.ReentrantLock;
 
-import javax.jms.IllegalStateException;
-import javax.jms.JMSException;
-import javax.jms.Message;
-import javax.jms.MessageConsumer;
-import javax.jms.MessageFormatException;
-import javax.jms.MessageListener;
-import javax.jms.Session;
+import jakarta.jms.IllegalStateException;
+import jakarta.jms.JMSException;
+import jakarta.jms.Message;
+import jakarta.jms.MessageConsumer;
+import jakarta.jms.MessageFormatException;
+import jakarta.jms.MessageListener;
+import jakarta.jms.Session;
 
+import org.apache.qpid.jms.exceptions.JmsConnectionFailedException;
 import org.apache.qpid.jms.exceptions.JmsExceptionSupport;
 import org.apache.qpid.jms.message.JmsInboundMessageDispatch;
 import org.apache.qpid.jms.message.JmsMessage;
@@ -42,7 +43,12 @@ import org.apache.qpid.jms.policy.JmsPrefetchPolicy;
 import org.apache.qpid.jms.policy.JmsRedeliveryPolicy;
 import org.apache.qpid.jms.provider.Provider;
 import org.apache.qpid.jms.provider.ProviderConstants.ACK_TYPE;
+import org.apache.qpid.jms.provider.ProviderException;
 import org.apache.qpid.jms.provider.ProviderFuture;
+import org.apache.qpid.jms.provider.ProviderSynchronization;
+import org.apache.qpid.jms.tracing.JmsTracer;
+import org.apache.qpid.jms.tracing.JmsTracer.DeliveryOutcome;
+import org.apache.qpid.jms.tracing.TraceableMessage;
 import org.apache.qpid.jms.util.FifoMessageQueue;
 import org.apache.qpid.jms.util.MessageQueue;
 import org.apache.qpid.jms.util.PriorityMessageQueue;
@@ -65,10 +71,11 @@ public class JmsMessageConsumer implements AutoCloseable, MessageConsumer, JmsMe
     protected volatile JmsMessageAvailableListener availableListener;
     protected final MessageQueue messageQueue;
     protected final Lock lock = new ReentrantLock();
-    protected final Lock dispatchLock = new ReentrantLock();
-    protected final AtomicBoolean suspendedConnection = new AtomicBoolean();
+    protected final ReentrantLock dispatchLock = new ReentrantLock();
     protected final AtomicReference<Throwable> failureCause = new AtomicReference<>();
     protected final MessageDeliverTask deliveryTask = new MessageDeliverTask();
+    protected final JmsTracer tracer;
+    protected final String address;
 
     protected JmsMessageConsumer(JmsConsumerId consumerId, JmsSession session, JmsDestination destination,
                                  String selector, boolean noLocal) throws JMSException {
@@ -79,23 +86,27 @@ public class JmsMessageConsumer implements AutoCloseable, MessageConsumer, JmsMe
                                  String name, String selector, boolean noLocal) throws JMSException {
         this.session = session;
         this.connection = session.getConnection();
+        this.tracer = connection.getTracer();
+        this.address = destination.getAddress();
         this.acknowledgementMode = isBrowser() ? Session.AUTO_ACKNOWLEDGE : session.acknowledgementMode();
 
         if (destination.isTemporary()) {
             connection.checkConsumeFromTemporaryDestination((JmsTemporaryDestination) destination);
         }
 
-        if (connection.isLocalMessagePriority()) {
-            this.messageQueue = new PriorityMessageQueue();
-        } else {
-            this.messageQueue = new FifoMessageQueue();
-        }
-
         JmsPrefetchPolicy prefetchPolicy = session.getPrefetchPolicy();
         JmsRedeliveryPolicy redeliveryPolicy = session.getRedeliveryPolicy().copy();
         JmsDeserializationPolicy deserializationPolicy = session.getDeserializationPolicy().copy();
 
-        consumerInfo = new JmsConsumerInfo(consumerId, messageQueue);
+        int configuredPrefetch = prefetchPolicy.getConfiguredPrefetch(session, destination, isDurableSubscription(), isBrowser());
+
+        if (connection.isLocalMessagePriority()) {
+            this.messageQueue = new PriorityMessageQueue();
+        } else {
+            this.messageQueue = new FifoMessageQueue(configuredPrefetch);
+        }
+
+        consumerInfo = new JmsConsumerInfo(consumerId, this);
         consumerInfo.setExplicitClientID(connection.isExplicitClientID());
         consumerInfo.setSelector(selector);
         consumerInfo.setDurable(isDurableSubscription());
@@ -105,19 +116,26 @@ public class JmsMessageConsumer implements AutoCloseable, MessageConsumer, JmsMe
         consumerInfo.setAcknowledgementMode(acknowledgementMode);
         consumerInfo.setNoLocal(noLocal);
         consumerInfo.setBrowser(isBrowser());
-        consumerInfo.setPrefetchSize(
-            prefetchPolicy.getConfiguredPrefetch(session, destination, isDurableSubscription(), isBrowser()));
+        consumerInfo.setPrefetchSize(configuredPrefetch);
         consumerInfo.setRedeliveryPolicy(redeliveryPolicy);
         consumerInfo.setLocalMessageExpiry(connection.isLocalMessageExpiry());
         consumerInfo.setPresettle(session.getPresettlePolicy().isConsumerPresttled(session, destination));
         consumerInfo.setDeserializationPolicy(deserializationPolicy);
 
-        session.add(this);
-        try {
-            session.getConnection().createResource(consumerInfo);
-        } catch (JMSException jmse) {
-            session.remove(this);
-            throw jmse;
+        session.getConnection().createResource(consumerInfo, new ProviderSynchronization() {
+
+            @Override
+            public void onPendingSuccess() {
+                session.add(JmsMessageConsumer.this);
+            }
+
+            @Override
+            public void onPendingFailure(ProviderException cause) {
+            }
+        });
+
+        if (session.isStarted()) {
+            start();
         }
     }
 
@@ -151,7 +169,10 @@ public class JmsMessageConsumer implements AutoCloseable, MessageConsumer, JmsMe
      */
     protected void doClose() throws JMSException {
         shutdown();
-        this.connection.destroyResource(consumerInfo);
+        try {
+            this.connection.destroyResource(consumerInfo);
+        } catch (JmsConnectionFailedException jmsex) {
+        }
     }
 
     /**
@@ -316,16 +337,26 @@ public class JmsMessageConsumer implements AutoCloseable, MessageConsumer, JmsMe
                             // closed until future pulls were performed.
                         }
                     }
-                } else if (consumeExpiredMessage(envelope)) {
+
+                    continue;
+                }
+
+                TraceableMessage facade = envelope.getMessage().getFacade();
+
+                if (consumeExpiredMessage(envelope)) {
                     LOG.trace("{} filtered expired message: {}", getConsumerId(), envelope);
                     doAckExpired(envelope);
+                    tracer.syncReceive(facade, address, DeliveryOutcome.EXPIRED);
+
                     if (timeout > 0) {
                         timeout = Math.max(deadline - System.currentTimeMillis(), 0);
                     }
                     performPullIfRequired(timeout, false);
-                } else if (redeliveryExceeded(envelope)) {
+                } else if (session.redeliveryExceeded(envelope)) {
                     LOG.debug("{} filtered message with excessive redelivery count: {}", getConsumerId(), envelope);
                     applyRedeliveryPolicyOutcome(envelope);
+                    tracer.syncReceive(facade, address, DeliveryOutcome.REDELIVERIES_EXCEEDED);
+
                     if (timeout > 0) {
                         timeout = Math.max(deadline - System.currentTimeMillis(), 0);
                     }
@@ -334,6 +365,9 @@ public class JmsMessageConsumer implements AutoCloseable, MessageConsumer, JmsMe
                     if (LOG.isTraceEnabled()) {
                         LOG.trace(getConsumerId() + " received message: " + envelope);
                     }
+
+                    tracer.syncReceive(facade, address, DeliveryOutcome.DELIVERED);
+
                     return envelope;
                 }
             }
@@ -351,15 +385,6 @@ public class JmsMessageConsumer implements AutoCloseable, MessageConsumer, JmsMe
         return false;
     }
 
-    protected boolean redeliveryExceeded(JmsInboundMessageDispatch envelope) {
-        LOG.trace("checking envelope with {} redeliveries", envelope.getRedeliveryCount());
-
-        JmsRedeliveryPolicy redeliveryPolicy = consumerInfo.getRedeliveryPolicy();
-        return redeliveryPolicy != null &&
-               redeliveryPolicy.getMaxRedeliveries(getDestination()) >= 0 &&
-               redeliveryPolicy.getMaxRedeliveries(getDestination()) < envelope.getRedeliveryCount();
-    }
-
     protected void checkClosed() throws IllegalStateException {
         if (closed.get()) {
             IllegalStateException jmsEx = null;
@@ -391,7 +416,13 @@ public class JmsMessageConsumer implements AutoCloseable, MessageConsumer, JmsMe
         if (envelope == null || envelope.getMessage() == null) {
             return null;
         }
-        return envelope.getMessage().copy();
+
+        try {
+            return envelope.getMessage().copy();
+        } catch (Exception ex) {
+            session.acknowledge(envelope, ACK_TYPE.MODIFIED_FAILED_UNDELIVERABLE);
+            throw ex;
+        }
     }
 
     JmsInboundMessageDispatch ackFromReceive(final JmsInboundMessageDispatch envelope) throws JMSException {
@@ -412,7 +443,7 @@ public class JmsMessageConsumer implements AutoCloseable, MessageConsumer, JmsMe
         try {
             session.acknowledge(envelope, ACK_TYPE.ACCEPTED);
         } catch (JMSException ex) {
-            session.onException(ex);
+            signalExceptionListener(ex);
             throw ex;
         }
         return envelope;
@@ -422,7 +453,7 @@ public class JmsMessageConsumer implements AutoCloseable, MessageConsumer, JmsMe
         try {
             session.acknowledge(envelope, ACK_TYPE.DELIVERED);
         } catch (JMSException ex) {
-            session.onException(ex);
+            signalExceptionListener(ex);
             throw ex;
         }
         return envelope;
@@ -432,7 +463,7 @@ public class JmsMessageConsumer implements AutoCloseable, MessageConsumer, JmsMe
         try {
             session.acknowledge(envelope, ACK_TYPE.MODIFIED_FAILED_UNDELIVERABLE);
         } catch (JMSException ex) {
-            session.onException(ex);
+            signalExceptionListener(ex);
             throw ex;
         }
     }
@@ -442,7 +473,7 @@ public class JmsMessageConsumer implements AutoCloseable, MessageConsumer, JmsMe
             JmsRedeliveryPolicy redeliveryPolicy = consumerInfo.getRedeliveryPolicy();
             session.acknowledge(envelope, lookupAckTypeForDisposition(redeliveryPolicy.getOutcome(getDestination())));
         } catch (JMSException ex) {
-            session.onException(ex);
+            signalExceptionListener(ex);
             throw ex;
         }
     }
@@ -451,7 +482,7 @@ public class JmsMessageConsumer implements AutoCloseable, MessageConsumer, JmsMe
         try {
             session.acknowledge(envelope, ACK_TYPE.RELEASED);
         } catch (JMSException ex) {
-            session.onException(ex);
+            signalExceptionListener(ex);
             throw ex;
         }
     }
@@ -465,10 +496,14 @@ public class JmsMessageConsumer implements AutoCloseable, MessageConsumer, JmsMe
      */
     @Override
     public void onInboundMessage(final JmsInboundMessageDispatch envelope) {
+        envelope.setConsumerInfo(consumerInfo);
+
         lock.lock();
         try {
             if (acknowledgementMode == Session.CLIENT_ACKNOWLEDGE) {
                 envelope.getMessage().setAcknowledgeCallback(new JmsAcknowledgeCallback(session));
+            } else if (session.isIndividualAcknowledge()) {
+                envelope.getMessage().setAcknowledgeCallback(new JmsAcknowledgeCallback(session, envelope));
             }
 
             if (envelope.isEnqueueFirst()) {
@@ -649,16 +684,24 @@ public class JmsMessageConsumer implements AutoCloseable, MessageConsumer, JmsMe
     }
 
     protected void onConnectionRecovery(Provider provider) throws Exception {
-        if (consumerInfo.isOpen()) {
-            ProviderFuture request = new ProviderFuture();
-            provider.create(consumerInfo, request);
-            request.sync();
+        if (!consumerInfo.isClosed()) {
+            ProviderFuture request = provider.newProviderFuture();
+            try {
+                provider.create(consumerInfo, request);
+                request.sync();
+            } catch (ProviderException poe) {
+                if (connection.isCloseLinksThatFailOnReconnect()) {
+                    session.consumerClosed(consumerInfo, poe);
+                } else {
+                    throw poe;
+                }
+            }
         }
     }
 
     protected void onConnectionRecovered(Provider provider) throws Exception {
-        if (consumerInfo.isOpen()) {
-            ProviderFuture request = new ProviderFuture();
+        if (!consumerInfo.isClosed()) {
+            ProviderFuture request = provider.newProviderFuture();
             provider.start(consumerInfo, request);
             request.sync();
         }
@@ -693,6 +736,25 @@ public class JmsMessageConsumer implements AutoCloseable, MessageConsumer, JmsMe
         return false;
     }
 
+    private final void signalExceptionListener(Exception ex) {
+        boolean reclaimLock = false;
+
+        if (dispatchLock.isHeldByCurrentThread()) {
+            reclaimLock = true;
+            session.setDeliveryThreadCheckEnabled(false);
+            dispatchLock.unlock();
+        }
+
+        try {
+            session.onException(ex);
+        } finally {
+            if (reclaimLock) {
+                dispatchLock.lock();
+                session.setDeliveryThreadCheckEnabled(true);
+            }
+        }
+    }
+
     private void drainMessageQueueToListener() {
         if (messageListener != null && session.isStarted() && messageQueue.isRunning()) {
             session.getDispatcherExecutor().execute(new BoundedMessageDeliverTask(messageQueue.size()));
@@ -708,15 +770,21 @@ public class JmsMessageConsumer implements AutoCloseable, MessageConsumer, JmsMe
                     return false;
                 }
 
-                JmsMessage copy = null;
+                TraceableMessage facade = envelope.getMessage().getFacade();
 
                 if (consumeExpiredMessage(envelope)) {
                     LOG.trace("{} filtered expired message: {}", getConsumerId(), envelope);
                     doAckExpired(envelope);
-                } else if (redeliveryExceeded(envelope)) {
+                    tracer.asyncDeliveryInit(facade, address);
+                    tracer.asyncDeliveryComplete(facade, DeliveryOutcome.EXPIRED, null);
+                } else if (session.redeliveryExceeded(envelope)) {
                     LOG.trace("{} filtered message with excessive redelivery count: {}", getConsumerId(), envelope);
                     applyRedeliveryPolicyOutcome(envelope);
+                    tracer.asyncDeliveryInit(facade, address);
+                    tracer.asyncDeliveryComplete(facade, DeliveryOutcome.REDELIVERIES_EXCEEDED, null);
                 } else {
+                    final JmsMessage copy;
+
                     boolean deliveryFailed = false;
                     boolean autoAckOrDupsOk = acknowledgementMode == Session.AUTO_ACKNOWLEDGE ||
                                               acknowledgementMode == Session.DUPS_OK_ACKNOWLEDGE;
@@ -728,9 +796,16 @@ public class JmsMessageConsumer implements AutoCloseable, MessageConsumer, JmsMe
                     session.clearSessionRecovered();
 
                     try {
+                        tracer.asyncDeliveryInit(facade, address);
+
                         messageListener.onMessage(copy);
                     } catch (RuntimeException rte) {
                         deliveryFailed = true;
+                        tracer.asyncDeliveryComplete(facade, DeliveryOutcome.APPLICATION_ERROR, rte);
+                    } finally {
+                        if (!deliveryFailed) {
+                            tracer.asyncDeliveryComplete(facade, DeliveryOutcome.DELIVERED, null);
+                        }
                     }
 
                     if (autoAckOrDupsOk && !session.isSessionRecovered()) {
@@ -742,11 +817,9 @@ public class JmsMessageConsumer implements AutoCloseable, MessageConsumer, JmsMe
                     }
                 }
             } catch (Exception e) {
-                // TODO - There are two cases where we can get an error here, one being
-                //        and error returned from the attempted ACK that was sent and the
-                //        other being an error while attempting to copy the incoming message.
-                //        We need to decide how to respond to these.
-                session.getConnection().onException(e);
+                // An error while attempting to copy the message is the likely cause of this
+                // exception case being hit.
+                signalExceptionListener(e);
             } finally {
                 dispatchLock.unlock();
 
