@@ -19,10 +19,10 @@
 package org.apache.qpid.jms.integration;
 
 import static org.hamcrest.Matchers.equalTo;
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertNull;
-import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
 
 import java.net.InetSocketAddress;
 import java.net.Socket;
@@ -34,11 +34,11 @@ import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.function.Supplier;
 
-import javax.jms.Connection;
-import javax.jms.JMSException;
-import javax.jms.MessageConsumer;
-import javax.jms.Queue;
-import javax.jms.Session;
+import jakarta.jms.Connection;
+import jakarta.jms.JMSException;
+import jakarta.jms.MessageConsumer;
+import jakarta.jms.Queue;
+import jakarta.jms.Session;
 import javax.net.ssl.SSLContext;
 import javax.net.ssl.SSLSocket;
 
@@ -54,9 +54,11 @@ import org.apache.qpid.jms.test.testpeer.TestAmqpPeer;
 import org.apache.qpid.jms.transports.TransportOptions;
 import org.apache.qpid.jms.transports.TransportSupport;
 import org.apache.qpid.jms.transports.netty.NettySimpleAmqpServer;
+import org.apache.qpid.jms.util.QpidJMSTestRunner;
+import org.apache.qpid.jms.util.Repeat;
 import org.apache.qpid.proton.amqp.UnsignedInteger;
-import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.Timeout;
+import org.junit.Test;
+import org.junit.runner.RunWith;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -64,14 +66,14 @@ import io.netty.handler.proxy.HttpProxyHandler;
 import io.netty.handler.proxy.ProxyHandler;
 import io.netty.handler.proxy.Socks5ProxyHandler;
 
+@RunWith(QpidJMSTestRunner.class)
 public class ProxyIntegrationTest extends QpidJmsTestCase {
     private static final Logger LOG = LoggerFactory.getLogger(ProxyIntegrationTest.class);
     private static final String BROKER_PKCS12_KEYSTORE = "src/test/resources/broker-pkcs12.keystore";
     private static final String CLIENT_JKS_TRUSTSTORE = "src/test/resources/client-jks.truststore";
     private static final String PASSWORD = "password";
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testCreateConnectionViaSocksProxy() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();
              TestProxy testProxy = new TestProxy(ProxyType.SOCKS5)) {
@@ -89,12 +91,11 @@ public class ProxyIntegrationTest extends QpidJmsTestCase {
             connection.close();
 
             assertEquals(1, testProxy.getSuccessCount());
-            assertEquals(1, supplierUsageCount.get(), "Unexpected handler supplier usage count");
+            assertEquals("Unexpected handler supplier usage count", 1, supplierUsageCount.get());
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testCreateSecureConnectionViaSocksProxy() throws Exception {
         TransportOptions sslOptions = new TransportOptions();
         sslOptions.setKeyStoreLocation(BROKER_PKCS12_KEYSTORE);
@@ -123,12 +124,12 @@ public class ProxyIntegrationTest extends QpidJmsTestCase {
             connection.close();
 
             assertEquals(1, testProxy.getSuccessCount());
-            assertEquals(1, supplierUsageCount.get(), "Unexpected handler supplier usage count");
+            assertEquals("Unexpected handler supplier usage count", 1, supplierUsageCount.get());
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Repeat(repetitions = 1)
+    @Test(timeout = 20000)
     public void testFailoverCreateConsumerAfterConnectionDropsViaSocksProxy() throws Exception {
         try (TestAmqpPeer originalPeer = new TestAmqpPeer();
              TestAmqpPeer finalPeer = new TestAmqpPeer();
@@ -181,8 +182,8 @@ public class ProxyIntegrationTest extends QpidJmsTestCase {
             });
             connection.start();
 
-            assertTrue(originalConnected.await(5, TimeUnit.SECONDS), "Should connect to original peer");
-            assertEquals(1, supplierUsageCount.get(), "Unexpected handler supplier usage count");
+            assertTrue("Should connect to original peer", originalConnected.await(5, TimeUnit.SECONDS));
+            assertEquals("Unexpected handler supplier usage count", 1, supplierUsageCount.get());
 
             // --- Post Failover Expectations of FinalPeer --- //
 
@@ -203,7 +204,7 @@ public class ProxyIntegrationTest extends QpidJmsTestCase {
             assertNull(consumer.receive(500));
             LOG.info("Receive returned");
 
-            assertTrue(finalConnected.await(5, TimeUnit.SECONDS), "Should connect to final peer");
+            assertTrue("Should connect to final peer", finalConnected.await(5, TimeUnit.SECONDS));
 
             LOG.info("Closing consumer");
             consumer.close();
@@ -215,18 +216,16 @@ public class ProxyIntegrationTest extends QpidJmsTestCase {
 
             // connection to originalPeer and finalPeer
             assertEquals(2, testProxy.getSuccessCount());
-            assertEquals(2, supplierUsageCount.get(), "Unexpected handler supplier usage count");
+            assertEquals("Unexpected handler supplier usage count", 2, supplierUsageCount.get());
         }
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testCreateWebSocketConnectionViaHttpProxyAndStart() throws Exception {
         doTestCreateWebSocketConnectionViaHttpProxyAndStart(false);
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testCreateSecureWebSocketConnectionViaHttpProxyAndStart() throws Exception {
         doTestCreateWebSocketConnectionViaHttpProxyAndStart(true);
     }
@@ -275,18 +274,16 @@ public class ProxyIntegrationTest extends QpidJmsTestCase {
             connection.close();
 
             assertEquals(1, testProxy.getSuccessCount());
-            assertTrue(connectedThroughProxy.get(), "Client did not connect to test server through the proxy.");
+            assertTrue("Client did not connect to test server through the proxy.", connectedThroughProxy.get());
         }
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testCreateWebSocketConnectionViaSocksProxyAndStart() throws Exception {
         doTestCreateWebSocketConnectionViaSocksProxyAndStart(false);
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testCreateSecureWebSocketConnectionViaSocksProxyAndStart() throws Exception {
         doTestCreateWebSocketConnectionViaSocksProxyAndStart(true);
     }
@@ -335,7 +332,7 @@ public class ProxyIntegrationTest extends QpidJmsTestCase {
             connection.close();
 
             assertEquals(1, testProxy.getSuccessCount());
-            assertTrue(connectedThroughProxy.get(), "Client did not connect to test server through the proxy.");
+            assertTrue("Client did not connect to test server through the proxy.", connectedThroughProxy.get());
         }
     }
 
