@@ -21,23 +21,23 @@ package org.apache.qpid.jms.integration;
 import static org.apache.qpid.jms.provider.amqp.AmqpSupport.SHARED_SUBS;
 import static org.apache.qpid.jms.provider.amqp.AmqpSupport.SUB_NAME_DELIMITER;
 import static org.hamcrest.Matchers.equalTo;
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-import static org.junit.jupiter.api.Assertions.fail;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
 import java.io.IOException;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.TimeUnit;
 
-import javax.jms.Connection;
-import javax.jms.ConnectionFactory;
-import javax.jms.InvalidDestinationException;
-import javax.jms.JMSException;
-import javax.jms.MessageConsumer;
-import javax.jms.Session;
-import javax.jms.Topic;
-import javax.jms.TopicSubscriber;
+import jakarta.jms.Connection;
+import jakarta.jms.ConnectionFactory;
+import jakarta.jms.InvalidDestinationException;
+import jakarta.jms.JMSException;
+import jakarta.jms.MessageConsumer;
+import jakarta.jms.Session;
+import jakarta.jms.Topic;
+import jakarta.jms.TopicSubscriber;
 
 import org.apache.qpid.jms.JmsConnection;
 import org.apache.qpid.jms.JmsConnectionFactory;
@@ -48,8 +48,7 @@ import org.apache.qpid.jms.test.testpeer.TestAmqpPeer;
 import org.apache.qpid.jms.test.testpeer.basictypes.AmqpError;
 import org.apache.qpid.proton.amqp.Symbol;
 import org.hamcrest.Matcher;
-import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.Timeout;
+import org.junit.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -74,8 +73,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testCloseSharedDurableTopicSubscriberDetachesWithCloseFalse() throws Exception {
         doSharedTopicSubscriberDetachTestImpl(true);
     }
@@ -85,8 +83,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testCloseSharedVolatileTopicSubscriberDetachesWithCloseTrue() throws Exception {
         doSharedTopicSubscriberDetachTestImpl(false);
     }
@@ -140,8 +137,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testSharedDurableSubscriberLinkNames() throws Exception {
         doSharedSubsriberLinkNamesHaveUniqueCounterSuffixTestImpl(true, true);
     }
@@ -152,8 +148,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testSharedVolatileSubscriberLinkNamesHaveUniqueCounterSuffix() throws Exception {
         doSharedSubsriberLinkNamesHaveUniqueCounterSuffixTestImpl(false, true);
     }
@@ -165,8 +160,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testSharedDurableSubscriberLinkNamesNoClientID() throws Exception {
         doSharedSubsriberLinkNamesHaveUniqueCounterSuffixTestImpl(true, false);
     }
@@ -178,8 +172,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testSharedVolatileSubscriberLinkNamesHaveUniqueCounterSuffixNoClientID() throws Exception {
         doSharedSubsriberLinkNamesHaveUniqueCounterSuffixTestImpl(false, false);
     }
@@ -269,8 +262,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testSharedDurableSubsriberLinkNamesMultipleConnectionSubs() throws Exception {
         doMultipleConnectionSharedSubscriberLinkNamesHaveUniqueCounterSuffixTestImpl(true);
     }
@@ -281,8 +273,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testSharedVolatileSubsriberLinkNamesHaveUniqueCounterSuffixMultipleConnectionSubs() throws Exception {
         doMultipleConnectionSharedSubscriberLinkNamesHaveUniqueCounterSuffixTestImpl(false);
     }
@@ -361,8 +352,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testSharedDurableSubsriberLinkNamesMultipleSessionSubs() throws Exception {
         doMultipleSessionSharedSubscriberLinkNamesHaveUniqueCounterSuffixTestImpl(true);
     }
@@ -373,8 +363,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testSharedVolatileSubsriberLinkNamesHaveUniqueCounterSuffixMultipleSessionSubs() throws Exception {
         doMultipleSessionSharedSubscriberLinkNamesHaveUniqueCounterSuffixTestImpl(false);
     }
@@ -444,8 +433,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testSharedDurableSubsriberLinkNamesMultipleNamedSubs() throws Exception {
         doMultipleNamedSharedSubscriberLinkNamesHaveUniqueCounterSuffixTestImpl(true);
     }
@@ -456,8 +444,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testSharedVolatileSubsriberLinkNamesHaveUniqueCounterSuffixMultipleNamedSubs() throws Exception {
         doMultipleNamedSharedSubscriberLinkNamesHaveUniqueCounterSuffixTestImpl(false);
     }
@@ -542,8 +529,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testSharedDurableAndVolatileSubsCoexistUsingDistinctLinkNames() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             // Add server connection capability to indicate support for shared-subs
@@ -590,8 +576,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testCreateSharedDurableTopicSubscriberFailsIfNotSupported() throws Exception {
         doSharedSubscriptionNotSupportedTestImpl(true, false);
     }
@@ -603,8 +588,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testCreateSharedVolatileTopicSubscriberFailsIfNotSupported() throws Exception {
         doSharedSubscriptionNotSupportedTestImpl(false, false);
     }
@@ -617,8 +601,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testCreateSharedDurableTopicSubscriberFailsIfNotSupportedReleasesLinkName() throws Exception {
         doSharedSubscriptionNotSupportedTestImpl(true, true);
     }
@@ -631,8 +614,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testCreateSharedVolatileTopicSubscriberFailsIfNotSupportedReleasesLinkName() throws Exception {
         doSharedSubscriptionNotSupportedTestImpl(false, true);
     }
@@ -693,8 +675,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testCreateSharedDurableTopicSubscriberSucceedsWithOnlyLinkCapability() throws Exception {
         doSharedSubscriptionLinkCapabilitySupportedTestImpl(true);
     }
@@ -706,8 +687,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testCreateSharedVolatileTopicSubscriberSucceedsWithOnlyLinkCapability() throws Exception {
         doSharedSubscriptionLinkCapabilitySupportedTestImpl(false);
     }
@@ -759,8 +739,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testSharedAndExclusiveDurableSubsCantCoexistSharedFirst() throws Exception {
         doSharedAndExclusiveDurableSubsCantCoexistTestImpl(true);
     }
@@ -771,8 +750,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testSharedAndExclusiveDurableSubsCantCoexistExclusiveFirst() throws Exception {
         doSharedAndExclusiveDurableSubsCantCoexistTestImpl(false);
     }
@@ -831,8 +809,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
 
     // -------------------------------------- //
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testExclusiveDurableSubCanOnlyBeActiveOnceAtATime() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             // Establish connection
@@ -886,8 +863,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testUnsubscribeNonExistingSubscription() throws Exception {
         doUnsubscribeNonExistingSubscriptionTestImpl(true);
     }
@@ -900,8 +876,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testUnsubscribeNonExistingSubscriptionWithoutClientID() throws Exception {
         doUnsubscribeNonExistingSubscriptionTestImpl(false);
     }
@@ -948,8 +923,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testUnsubscribeExclusiveDurableSubWhileActiveThenInactive() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
@@ -967,7 +941,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
             testPeer.expectLinkFlow();
 
             TopicSubscriber subscriber = session.createDurableSubscriber(dest, subscriptionName);
-            assertNotNull(subscriber, "TopicSubscriber object was null");
+            assertNotNull("TopicSubscriber object was null", subscriber);
 
             // Now try to unsubscribe, should fail
             try {
@@ -1003,8 +977,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testUnsubscribeSharedDurableSubWhileActiveThenInactive() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             // Add server connection capability to indicate support for shared-subs
@@ -1089,8 +1062,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testUnsubscribeAfterFailedCreation() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             // Add server connection capability to indicate support for shared-subs
@@ -1141,8 +1113,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testUnsubscribeFailsWhenRemoteDetachResponseIndicatesFailure() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
@@ -1182,8 +1153,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected error is encountered
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testRemotelyDetachLinkWithDurableSharedConsumer() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             // Add server connection capability to indicate support for shared-subs
@@ -1232,7 +1202,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
             MessageConsumer subscriber2 = session2.createSharedDurableConsumer(dest,  subscriptionName);
             assertNotNull(subscriber2);
 
-            assertTrue(subscriberClosed.await(5, TimeUnit.SECONDS), "Consumer closed callback didn't trigger");
+            assertTrue("Consumer closed callback didn't trigger", subscriberClosed.await(5, TimeUnit.SECONDS));
 
             testPeer.waitForAllHandlersToComplete(1000);
 
@@ -1271,8 +1241,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testSharedDurableSubChangeOfTopic() throws Exception {
         doSharedSubChangeOfDetailsTestImpl(true, true, false);
     }
@@ -1284,8 +1253,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testSharedVolatileSubChangeOfTopic() throws Exception {
         doSharedSubChangeOfDetailsTestImpl(false, true, false);
     }
@@ -1297,8 +1265,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testSharedDurableSubChangeOfSelector() throws Exception {
         doSharedSubChangeOfDetailsTestImpl(true, false, true);
     }
@@ -1310,8 +1277,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testSharedVolatileSubChangeOfSelector() throws Exception {
         doSharedSubChangeOfDetailsTestImpl(false, false, true);
     }
@@ -1323,8 +1289,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testSharedDurableSubChangeOfTopicAndSelector() throws Exception {
         doSharedSubChangeOfDetailsTestImpl(true, true, true);
     }
@@ -1336,8 +1301,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testSharedVolatileSubChangeOfTopicAndSelector() throws Exception {
         doSharedSubChangeOfDetailsTestImpl(false, true, true);
     }
@@ -1443,8 +1407,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected error is encountered
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testRemotelyEndSessionWithDurableSharedConsumer() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             // Add server connection capability to indicate support for shared-subs
@@ -1493,7 +1456,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
             MessageConsumer subscriber2 = session2.createSharedDurableConsumer(dest,  subscriptionName);
             assertNotNull(subscriber2);
 
-            assertTrue(sessionClosed.await(5, TimeUnit.SECONDS), "Session closed callback didn't trigger");
+            assertTrue("Session closed callback didn't trigger", sessionClosed.await(5, TimeUnit.SECONDS));
 
             testPeer.waitForAllHandlersToComplete(1000);
 
@@ -1528,8 +1491,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected error is encountered
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testLocallyEndSessionWithSharedConsumer() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             // Add server connection capability to indicate support for shared-subs
@@ -1613,8 +1575,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected error is encountered
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testSubscriptionNameNotAllowedToHaveNameSeparator() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             // Add server connection capability to indicate support for shared-subs
@@ -1679,8 +1640,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
 
     // -------------------------------------- //
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testSharedTopicSubscriberBehavesLikeNoClientIDWasSetWhenAwaitClientIdOptionIsFalse() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             int serverPort = testPeer.getServerPort();
