@@ -16,26 +16,25 @@
  */
 package org.apache.qpid.jms.message;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertFalse;
-import static org.junit.jupiter.api.Assertions.assertNull;
-import static org.junit.jupiter.api.Assertions.assertThrows;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-import static org.junit.jupiter.api.Assertions.fail;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Enumeration;
 import java.util.List;
 
-import javax.jms.JMSException;
-import javax.jms.MessageFormatException;
-import javax.jms.MessageNotWriteableException;
+import jakarta.jms.JMSException;
+import jakarta.jms.MessageFormatException;
+import jakarta.jms.MessageNotWriteableException;
 
 import org.apache.qpid.jms.message.facade.JmsMapMessageFacade;
 import org.apache.qpid.jms.message.facade.test.JmsTestMapMessageFacade;
 import org.apache.qpid.jms.message.facade.test.JmsTestMessageFactory;
-import org.junit.jupiter.api.Test;
+import org.junit.Test;
 
 /**
  * Test that the JMS level JmsMapMessage using a simple default message facade follows
@@ -58,7 +57,7 @@ public class JmsMapMessageTest {
         JmsMapMessage mapMessage = factory.createMapMessage();
         Enumeration<?> names = mapMessage.getMapNames();
 
-        assertFalse(names.hasMoreElements(), "Expected new message to have no map names");
+        assertFalse("Expected new message to have no map names", names.hasMoreElements());
     }
 
     /**
@@ -84,9 +83,9 @@ public class JmsMapMessageTest {
             count++;
             elements.add(names.nextElement());
         }
-        assertEquals(2, count, "expected 2 map keys in enumeration");
-        assertTrue(elements.contains(myKey1), "expected key was not found: " + myKey1);
-        assertTrue(elements.contains(myKey2), "expected key was not found: " + myKey2);
+        assertEquals("expected 2 map keys in enumeration", 2, count);
+        assertTrue("expected key was not found: " + myKey1, elements.contains(myKey1));
+        assertTrue("expected key was not found: " + myKey2, elements.contains(myKey2));
     }
 
     /**
@@ -149,9 +148,9 @@ public class JmsMapMessageTest {
         JmsMapMessage mapMessage = new JmsMapMessage(facade);
         mapMessage.onDispatch();
 
-        assertTrue(mapMessage.isReadOnlyBody(), "expected message to be read-only");
+        assertTrue("expected message to be read-only", mapMessage.isReadOnlyBody());
         mapMessage.clearBody();
-        assertFalse(mapMessage.isReadOnlyBody(), "expected message to be writable");
+        assertFalse("expected message to be writable", mapMessage.isReadOnlyBody());
         mapMessage.setObject("name", "value");
     }
 
@@ -169,9 +168,9 @@ public class JmsMapMessageTest {
 
         JmsMapMessage mapMessage = new JmsMapMessage(facade);
 
-        assertTrue(mapMessage.itemExists(myKey1), "key should exist: " + myKey1);
+        assertTrue("key should exist: " + myKey1, mapMessage.itemExists(myKey1));
         mapMessage.clearBody();
-        assertFalse(mapMessage.itemExists(myKey1), "key should not exist");
+        assertFalse("key should not exist", mapMessage.itemExists(myKey1));
     }
 
     /**
@@ -217,12 +216,10 @@ public class JmsMapMessageTest {
      *
      * @throws Exception if an error occurs during the test.
      */
-    @Test
+    @Test(expected=MessageFormatException.class)
     public void testSetObjectWithIllegalTypeThrowsMFE() throws Exception {
-        assertThrows(MessageFormatException.class, () -> {
-            JmsMapMessage mapMessage = factory.createMapMessage();
-            mapMessage.setObject("myPKey", new Exception());
-        });
+        JmsMapMessage mapMessage = factory.createMapMessage();
+        mapMessage.setObject("myPKey", new Exception());
     }
 
     @Test
@@ -386,12 +383,12 @@ public class JmsMapMessageTest {
         boolean value = true;
 
         mapMessage.setBoolean(name, value);
-        assertEquals(value, mapMessage.getBoolean(name), "value not as expected");
+        assertEquals("value not as expected", value, mapMessage.getBoolean(name));
 
         assertGetMapEntryEquals(mapMessage, name, String.valueOf(value), String.class);
 
         mapMessage.setBoolean(name, !value);
-        assertEquals(!value, mapMessage.getBoolean(name), "value not as expected");
+        assertEquals("value not as expected", !value, mapMessage.getBoolean(name));
 
         assertGetMapEntryEquals(mapMessage, name, String.valueOf(!value), String.class);
     }
