@@ -17,10 +17,10 @@
 package org.apache.qpid.jms.provider.failover;
 
 import static org.apache.qpid.jms.provider.amqp.AmqpSupport.SCHEME;
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertFalse;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
 
 import java.lang.reflect.Field;
 import java.net.URI;
@@ -32,8 +32,8 @@ import java.util.Map;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.TimeUnit;
 
-import javax.jms.Connection;
-import javax.jms.ConnectionFactory;
+import jakarta.jms.Connection;
+import jakarta.jms.ConnectionFactory;
 import javax.net.ssl.SSLContext;
 
 import org.apache.qpid.jms.JmsConnection;
@@ -49,8 +49,7 @@ import org.apache.qpid.jms.util.PropertyUtil;
 import org.apache.qpid.jms.util.URISupport;
 import org.apache.qpid.proton.amqp.Symbol;
 import org.hamcrest.Matchers;
-import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.Timeout;
+import org.junit.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -79,8 +78,7 @@ public class FailoverWithAmqpOpenProvidedServerListIntegrationTest extends QpidJ
      * replace the servers in its existing URI pool, it does so, leaving the server successfully connected
      * to plus the announced failover servers.
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testFailoverHandlesServerProvidedFailoverListReplace() throws Exception {
         doFailoverHandlesServerProvidedFailoverListTestImpl(true);
     }
@@ -89,8 +87,7 @@ public class FailoverWithAmqpOpenProvidedServerListIntegrationTest extends QpidJ
      * Verify that when the Open frame contains a failover server list, and the client is configured to
      * add the servers to its existing URI pool, it does so.
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testFailoverHandlesServerProvidedFailoverListAdd() throws Exception {
         doFailoverHandlesServerProvidedFailoverListTestImpl(false);
     }
@@ -167,7 +164,7 @@ public class FailoverWithAmqpOpenProvidedServerListIntegrationTest extends QpidJ
             // Provoke the actual AMQP connection
             connection.start();
 
-            assertTrue(connectedToPrimary.await(5, TimeUnit.SECONDS), "Should connect to primary peer");
+            assertTrue("Should connect to primary peer", connectedToPrimary.await(5, TimeUnit.SECONDS));
 
             // Verify the failover URIs are as expected, now containing initial peer and the backup1
             List<URI> afterOpenFailoverURIs = new ArrayList<>();
@@ -194,8 +191,8 @@ public class FailoverWithAmqpOpenProvidedServerListIntegrationTest extends QpidJ
             // Kill the primary peer
             primaryPeer.close();
 
-            assertTrue(connectedToBackup1.await(5, TimeUnit.SECONDS), "Should connect to backup1 peer");
-            assertEquals(1, connectedToBackup2.getCount(), "Should not yet connect to backup2 peer");
+            assertTrue("Should connect to backup1 peer", connectedToBackup1.await(5, TimeUnit.SECONDS));
+            assertEquals("Should not yet connect to backup2 peer", 1, connectedToBackup2.getCount());
 
             // Verify the failover URIs are as expected
             List<URI> afterFirstReconnectFailoverURIs = new ArrayList<>();
@@ -220,7 +217,7 @@ public class FailoverWithAmqpOpenProvidedServerListIntegrationTest extends QpidJ
             // Kill the backup1 peer
             backupPeer1.close();
 
-            assertTrue(connectedToBackup2.await(5, TimeUnit.SECONDS), "Should connect to backup2 peer");
+            assertTrue("Should connect to backup2 peer", connectedToBackup2.await(5, TimeUnit.SECONDS));
 
             // Verify the failover URIs are as expected
             List<URI> afterSecondReconnectFailoverURIs = new ArrayList<>();
@@ -247,8 +244,7 @@ public class FailoverWithAmqpOpenProvidedServerListIntegrationTest extends QpidJ
      * Verify that when the Open frame contains a failover server list, and the client is configured to ignore it,
      * no change occurs in the failover URIs in use by the client after connecting.
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testFailoverHandlesServerProvidedFailoverListIgnore() throws Exception {
         try (TestAmqpPeer primaryPeer = new TestAmqpPeer();) {
 
@@ -298,7 +294,7 @@ public class FailoverWithAmqpOpenProvidedServerListIntegrationTest extends QpidJ
             // Provoke the actual AMQP connection
             connection.start();
 
-            assertTrue(connectedToPrimary.await(5, TimeUnit.SECONDS), "Should connect to primary peer");
+            assertTrue("Should connect to primary peer", connectedToPrimary.await(5, TimeUnit.SECONDS));
 
             // Verify the existing failover URIs are as expected, still the initial peer only
             assertFailoverURIList(connection, primaryPeerOnlyFailoverURIs);
@@ -313,8 +309,7 @@ public class FailoverWithAmqpOpenProvidedServerListIntegrationTest extends QpidJ
      * Verify that when the Open frame contains a failover server list, and it specifies an AMQP hostname in
      * a particular servers details, the hostname is used when failover occurs.
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testFailoverHandlesServerProvidedFailoverListWithHostname() throws Exception {
         try (TestAmqpPeer primaryPeer = new TestAmqpPeer();
              TestAmqpPeer backupPeer = new TestAmqpPeer();) {
@@ -376,7 +371,7 @@ public class FailoverWithAmqpOpenProvidedServerListIntegrationTest extends QpidJ
             // Provoke the actual AMQP connection
             connection.start();
 
-            assertTrue(connectedToPrimary.await(5, TimeUnit.SECONDS), "Should connect to primary peer");
+            assertTrue("Should connect to primary peer", connectedToPrimary.await(5, TimeUnit.SECONDS));
 
             // Verify the failover URIs are as expected, now containing initial peer and the backup (with vhost details)
             List<URI> afterOpenFailoverURIs = new ArrayList<>();
@@ -400,8 +395,7 @@ public class FailoverWithAmqpOpenProvidedServerListIntegrationTest extends QpidJ
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testFailoverHandlesRemoteCloseWithRedirectDuringConnectionSessionEstablishment() throws Exception {
         try (TestAmqpPeer primaryPeer = new TestAmqpPeer();
              TestAmqpPeer backupPeer = new TestAmqpPeer();) {
@@ -470,8 +464,8 @@ public class FailoverWithAmqpOpenProvidedServerListIntegrationTest extends QpidJ
 
             primaryPeer.waitForAllHandlersToComplete(3000);
 
-            assertTrue(connectedToBackup.await(5, TimeUnit.SECONDS), "Should connect to backup peer");
-            assertFalse(connectedToPrimary.await(10, TimeUnit.MILLISECONDS), "Should not connect to primary peer");
+            assertTrue("Should connect to backup peer", connectedToBackup.await(5, TimeUnit.SECONDS));
+            assertFalse("Should not connect to primary peer", connectedToPrimary.await(10, TimeUnit.MILLISECONDS));
 
             // Verify the failover URIs are as expected, now containing initial peer, its advertised third test-details peer, and the peer it then redirected to.
             List<URI> afterOpenFailoverURIs = new ArrayList<>();
@@ -491,8 +485,7 @@ public class FailoverWithAmqpOpenProvidedServerListIntegrationTest extends QpidJ
      * Verify that when the Open frame contains a failover server list and we are connected via SSL configured with
      * system properties the redirect uses those properties to connect to the new host.
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testFailoverUsingSSLConfiguredBySystemProperties() throws Exception {
         TransportOptions serverSslOptions = new TransportOptions();
         serverSslOptions.setKeyStoreLocation(BROKER_PKCS12_KEYSTORE);
@@ -563,7 +556,7 @@ public class FailoverWithAmqpOpenProvidedServerListIntegrationTest extends QpidJ
             // Provoke the actual AMQP connection
             connection.start();
 
-            assertTrue(connectedToPrimary.await(5, TimeUnit.SECONDS), "Should connect to primary peer");
+            assertTrue("Should connect to primary peer", connectedToPrimary.await(5, TimeUnit.SECONDS));
 
             // Verify the failover URIs are as expected, now containing initial peer and the backup1
             List<URI> afterOpenFailoverURIs = new ArrayList<>();
@@ -587,7 +580,7 @@ public class FailoverWithAmqpOpenProvidedServerListIntegrationTest extends QpidJ
             primaryPeer.waitForAllHandlersToComplete(1000);
             primaryPeer.close();
 
-            assertTrue(connectedToBackup.await(5, TimeUnit.SECONDS), "Should connect to backup peer");
+            assertTrue("Should connect to backup peer", connectedToBackup.await(5, TimeUnit.SECONDS));
 
             backupPeer.waitForAllHandlersToComplete(3000);
 
@@ -601,8 +594,7 @@ public class FailoverWithAmqpOpenProvidedServerListIntegrationTest extends QpidJ
      * Verify that when the Open frame contains a failover server list and we are connected via SSL configured with
      * URI options on the AMQP URI the redirect uses those properties to connect to the new host.
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testFailoverUsingSSLConfiguredByTransportOptions() throws Exception {
         TransportOptions sslOptions = new TransportOptions();
         sslOptions.setKeyStoreLocation(BROKER_PKCS12_KEYSTORE);
@@ -681,7 +673,7 @@ public class FailoverWithAmqpOpenProvidedServerListIntegrationTest extends QpidJ
             // Provoke the actual AMQP connection
             connection.start();
 
-            assertTrue(connectedToPrimary.await(5, TimeUnit.SECONDS), "Should connect to primary peer");
+            assertTrue("Should connect to primary peer", connectedToPrimary.await(5, TimeUnit.SECONDS));
 
             // Verify the failover URIs are as expected, now containing initial
             // peer and the backup1
@@ -706,7 +698,7 @@ public class FailoverWithAmqpOpenProvidedServerListIntegrationTest extends QpidJ
             primaryPeer.waitForAllHandlersToComplete(1000);
             primaryPeer.close();
 
-            assertTrue(connectedToBackup.await(5, TimeUnit.SECONDS), "Should connect to backup peer");
+            assertTrue("Should connect to backup peer", connectedToBackup.await(5, TimeUnit.SECONDS));
 
             backupPeer.waitForAllHandlersToComplete(3000);
 
@@ -721,8 +713,7 @@ public class FailoverWithAmqpOpenProvidedServerListIntegrationTest extends QpidJ
      * configured with the Failover URI with nested options the redirect uses those properties to
      * connect to the new host.
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testFailoverUsingSSLConfiguredByNestedTransportOptions() throws Exception {
         TransportOptions sslOptions = new TransportOptions();
         sslOptions.setKeyStoreLocation(BROKER_PKCS12_KEYSTORE);
@@ -801,7 +792,7 @@ public class FailoverWithAmqpOpenProvidedServerListIntegrationTest extends QpidJ
             // Provoke the actual AMQP connection
             connection.start();
 
-            assertTrue(connectedToPrimary.await(5, TimeUnit.SECONDS), "Should connect to primary peer");
+            assertTrue("Should connect to primary peer", connectedToPrimary.await(5, TimeUnit.SECONDS));
 
             // Verify the failover URIs are as expected, now containing initial
             // peer and the backup1
@@ -826,7 +817,7 @@ public class FailoverWithAmqpOpenProvidedServerListIntegrationTest extends QpidJ
             primaryPeer.waitForAllHandlersToComplete(1000);
             primaryPeer.close();
 
-            assertTrue(connectedToBackup.await(5, TimeUnit.SECONDS), "Should connect to backup peer");
+            assertTrue("Should connect to backup peer", connectedToBackup.await(5, TimeUnit.SECONDS));
 
             backupPeer.waitForAllHandlersToComplete(3000);
 
@@ -841,8 +832,7 @@ public class FailoverWithAmqpOpenProvidedServerListIntegrationTest extends QpidJ
      * configured with with a custom SSLContext the redirect uses those properties to connect to
      * the new host.
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testFailoverUsingSSLConfiguredByCustomSSLContext() throws Exception {
         TransportOptions serverSslOptions = new TransportOptions();
         serverSslOptions.setKeyStoreLocation(BROKER_PKCS12_KEYSTORE);
@@ -926,7 +916,7 @@ public class FailoverWithAmqpOpenProvidedServerListIntegrationTest extends QpidJ
             // Provoke the actual AMQP connection
             connection.start();
 
-            assertTrue(connectedToPrimary.await(5, TimeUnit.SECONDS), "Should connect to primary peer");
+            assertTrue("Should connect to primary peer", connectedToPrimary.await(5, TimeUnit.SECONDS));
 
             // Verify the failover URIs are as expected, now containing initial
             // peer and the backup1
@@ -951,7 +941,7 @@ public class FailoverWithAmqpOpenProvidedServerListIntegrationTest extends QpidJ
             primaryPeer.waitForAllHandlersToComplete(1000);
             primaryPeer.close();
 
-            assertTrue(connectedToBackup.await(5, TimeUnit.SECONDS), "Should connect to backup peer");
+            assertTrue("Should connect to backup peer", connectedToBackup.await(5, TimeUnit.SECONDS));
 
             backupPeer.waitForAllHandlersToComplete(3000);
 
@@ -966,8 +956,7 @@ public class FailoverWithAmqpOpenProvidedServerListIntegrationTest extends QpidJ
      * that a remote listed in the open frame failover list is ignored when insecure redirects are
      * prohibited.
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testFailoverIgnoresInsecureServerWhenNotConfiguredToAllow() throws Exception {
         doTestFailoverHandlingOfInsecureRedirectAdvertisement(false);
     }
@@ -977,8 +966,7 @@ public class FailoverWithAmqpOpenProvidedServerListIntegrationTest extends QpidJ
      * that a remote listed in the open frame failover list is accepted when insecure redirects are
      * allowed.
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testFailoverAcceptsInsecureServerWhenConfiguredToAllow() throws Exception {
         doTestFailoverHandlingOfInsecureRedirectAdvertisement(true);
     }
@@ -1052,7 +1040,7 @@ public class FailoverWithAmqpOpenProvidedServerListIntegrationTest extends QpidJ
             // Provoke the actual AMQP connection
             connection.start();
 
-            assertTrue(connectedToPrimary.await(5, TimeUnit.SECONDS), "Should connect to primary peer");
+            assertTrue("Should connect to primary peer", connectedToPrimary.await(5, TimeUnit.SECONDS));
 
             // Verify the failover URIs are as expected, now containing initial peer and if non-secure redirect
             // was permitted, the non-secure backup as well.
@@ -1075,8 +1063,7 @@ public class FailoverWithAmqpOpenProvidedServerListIntegrationTest extends QpidJ
      * the 'amqp' transport and the redirect contains a 'ws' scheme that failover reconnect list
      * is updated to contain the 'amqpws' redirect.
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testFailoverAcceptsUpdateUsingTransportSchemeWS() throws Exception {
         doTestFailoverAcceptsUpdateUsingTransportSchemes("ws", "amqpws");
     }
@@ -1086,8 +1073,7 @@ public class FailoverWithAmqpOpenProvidedServerListIntegrationTest extends QpidJ
      * the 'amqp' transport and the redirect contains a 'wss' scheme that failover reconnect list
      * is updated to contain the 'amqpwss' redirect.
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testFailoverAcceptsUpdateUsingTransportSchemeWSS() throws Exception {
         doTestFailoverAcceptsUpdateUsingTransportSchemes("wss", "amqpwss");
     }
@@ -1162,7 +1148,7 @@ public class FailoverWithAmqpOpenProvidedServerListIntegrationTest extends QpidJ
             // Provoke the actual AMQP connection
             connection.start();
 
-            assertTrue(connectedToPrimary.await(5, TimeUnit.SECONDS), "Should connect to primary peer");
+            assertTrue("Should connect to primary peer", connectedToPrimary.await(5, TimeUnit.SECONDS));
 
             // Verify the failover URIs are as expected, containing initial peer and a backup with expected uri scheme.
             List<URI> afterOpenFailoverURIs = new ArrayList<>();
@@ -1191,8 +1177,8 @@ public class FailoverWithAmqpOpenProvidedServerListIntegrationTest extends QpidJ
         urisField.setAccessible(true);
         Object urisObj = urisField.get(provider);
 
-        assertNotNull(urisObj, "Expected to get a uri pool instance");
-        assertTrue(urisObj instanceof FailoverUriPool, "Unexpected uri pool type: " + urisObj.getClass());
+        assertNotNull("Expected to get a uri pool instance", urisObj);
+        assertTrue("Unexpected uri pool type: " + urisObj.getClass(), urisObj instanceof FailoverUriPool);
         FailoverUriPool uriPool = (FailoverUriPool) urisObj;
 
         List<URI> current = uriPool.getList();
@@ -1204,8 +1190,8 @@ public class FailoverWithAmqpOpenProvidedServerListIntegrationTest extends QpidJ
         field.setAccessible(true);
         Object providerObj = field.get(connection);
 
-        assertNotNull(providerObj, "Expected to get a provdier instance");
-        assertTrue(providerObj instanceof FailoverProvider, "Unexpected provider type: " + providerObj.getClass());
+        assertNotNull("Expected to get a provdier instance", providerObj);
+        assertTrue("Unexpected provider type: " + providerObj.getClass(), providerObj instanceof FailoverProvider);
         FailoverProvider provider = (FailoverProvider) providerObj;
         return provider;
     }
