@@ -16,26 +16,27 @@
  */
 package org.apache.qpid.jms;
 
-import javax.jms.Connection;
+import jakarta.jms.Connection;
 
+import org.apache.activemq.junit.ActiveMQTestRunner;
+import org.apache.activemq.junit.Repeat;
 import org.apache.qpid.jms.support.AmqpTestSupport;
-import org.junit.jupiter.api.RepeatedTest;
-import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.Timeout;
+import org.junit.Test;
+import org.junit.runner.RunWith;
 
 /**
  * A test case for Connection close called under different circumstances.
  */
+@RunWith(ActiveMQTestRunner.class)
 public class JmsConnectionCloseVariationsTest extends AmqpTestSupport {
 
-    @Test
-    @Timeout(60)
+    @Test(timeout=60000)
     public void testCloseAfterBrokerStopped() throws Exception {
         doTestConnectionClosedAfterBrokerStopped();
     }
 
-    @RepeatedTest(25)
-    @Timeout(90)
+    @Repeat(repetitions = 25)
+    @Test(timeout=90000)
     public void testCloseAfterBrokerStoppedRepeated() throws Exception {
         doTestConnectionClosedAfterBrokerStopped();
     }
@@ -47,14 +48,13 @@ public class JmsConnectionCloseVariationsTest extends AmqpTestSupport {
         connection.close();
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout=60000)
     public void testCloseBeforeBrokerStopped() throws Exception {
         doTestConnectionClosedBeforeBrokerStopped();
     }
 
-    @RepeatedTest(25)
-    @Timeout(90)
+    @Repeat(repetitions = 25)
+    @Test(timeout=90000)
     public void testCloseBeforeBrokerStoppedRepeated() throws Exception {
         doTestConnectionClosedBeforeBrokerStopped();
     }
