@@ -16,28 +16,27 @@
  */
 package org.apache.qpid.jms.transactions;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertFalse;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertNull;
-import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
 
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.TimeUnit;
 
-import javax.jms.JMSException;
-import javax.jms.Message;
-import javax.jms.MessageConsumer;
-import javax.jms.MessageListener;
-import javax.jms.Queue;
-import javax.jms.Session;
-import javax.jms.TextMessage;
+import jakarta.jms.JMSException;
+import jakarta.jms.Message;
+import jakarta.jms.MessageConsumer;
+import jakarta.jms.MessageListener;
+import jakarta.jms.Queue;
+import jakarta.jms.Session;
+import jakarta.jms.TextMessage;
 
 import org.apache.activemq.broker.jmx.QueueViewMBean;
 import org.apache.qpid.jms.support.AmqpTestSupport;
 import org.apache.qpid.jms.support.Wait;
-import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.Timeout;
+import org.junit.Test;
 
 /**
  * test redelivery policy application in a TX session.
@@ -49,8 +48,7 @@ public class JmsTransactionRedeliveryPolicyTest extends AmqpTestSupport {
         return "jms.redeliveryPolicy.maxRedeliveries=5";
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testSyncConsumeAndRollbackWithMaxRedeliveries() throws Exception {
         final int MAX_REDELIVERIES = 5;
         final int MSG_COUNT = 5;
@@ -94,13 +92,13 @@ public class JmsTransactionRedeliveryPolicyTest extends AmqpTestSupport {
 
         assertNull(consumer.receive(50));
 
-        assertTrue(Wait.waitFor(new Wait.Condition() {
+        assertTrue("Message should get DLQ'd", Wait.waitFor(new Wait.Condition() {
 
             @Override
             public boolean isSatisfied() throws Exception {
                 return queueView.getQueueSize() == 0;
             }
-        }), "Message should get DLQ'd");
+        }));
 
         QueueViewMBean dlq = getProxyToQueue("ActiveMQ.DLQ");
         assertEquals(MSG_COUNT, dlq.getQueueSize());
@@ -108,8 +106,7 @@ public class JmsTransactionRedeliveryPolicyTest extends AmqpTestSupport {
         session.commit();
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testAsyncConsumeAndRollbackWithMaxRedeliveries() throws Exception {
         final int MAX_REDELIVERIES = 5;
         final int MSG_COUNT = 5;
@@ -141,7 +138,7 @@ public class JmsTransactionRedeliveryPolicyTest extends AmqpTestSupport {
             final CountDownLatch done = new CountDownLatch(MSG_COUNT);
             consumer.setMessageListener(new MaxRedeliveryListener(done, i));
 
-            assertTrue(done.await(10, TimeUnit.SECONDS), "Not All Messages Received");
+            assertTrue("Not All Messages Received", done.await(10, TimeUnit.SECONDS));
             assertEquals(MSG_COUNT, queueView.getQueueSize());
 
             consumer.setMessageListener(null);
@@ -151,13 +148,13 @@ public class JmsTransactionRedeliveryPolicyTest extends AmqpTestSupport {
 
         assertNull(consumer.receive(50));
 
-        assertTrue(Wait.waitFor(new Wait.Condition() {
+        assertTrue("Message should get DLQ'd", Wait.waitFor(new Wait.Condition() {
 
             @Override
             public boolean isSatisfied() throws Exception {
                 return queueView.getQueueSize() == 0;
             }
-        }), "Message should get DLQ'd");
+        }));
 
         QueueViewMBean dlq = getProxyToQueue("ActiveMQ.DLQ");
         assertEquals(MSG_COUNT, dlq.getQueueSize());
